@@ -2,11 +2,12 @@ package MongoDBx::Class::Cursor;
 
 # ABSTRACT: A MongoDBx::Class cursor/iterator object for query results
 
-our $VERSION = "1.01";
+our $VERSION = "1.02";
 $VERSION = eval $VERSION;
 
 use Moose;
 use namespace::autoclean;
+use version;
 
 extends 'MongoDB::Cursor';
 
@@ -16,7 +17,7 @@ MongoDBx::Class::Cursor - A MongoDBx::Class cursor/iterator object for query res
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 EXTENDS
 
@@ -83,6 +84,10 @@ around 'sort' => sub {
 	}
 };
 
+sub _connection {
+	version->parse($MongoDB::VERSION) < v0.502.0 ? $_[0]->SUPER : $_[0]->_client;
+}
+
 =head1 AUTHOR
 
 Ido Perlmuter, C<< <ido at ido50.net> >>
